# asteroloc8

## About

A Python package for producing a prior on the frequency at maximum power for TESS red giants. Examples of usage are found in the `notebooks` directory.

## Contributing

To contribute, please fork the repo using the button in the top-right of the GitHub page. If you are unsure what to do next, here are some instructions: Clone your own forked repository in the terminal using,

```
$ git clone https://github.com/YOUR-GITHUB-USERNAME/asteroloc8.git
```

Install `asteroloc8` in editable mode so your changes will update live in your environment,

```
$ cd asteroloc8
$ pip install -e .
```

If you want to fetch any changes from the `alexlyttle` remote then add it to your environment like so,

```
$ git remote add upstream https://github.com/alexlyttle/asteroloc8.git
```

To make your changes, create a branch with an appropriate name relating to the changes (e.g. the Issue number and sort name),

```
$ git checkout -b NAME-OF-YOUR-BRANCH
```

Make changes or additions to the code. Please make a Jupyter notebook in the `notebooks` folder demonstrating the usage of your code, or just a python script if you are more familiar with that.

Once your have made changes, commit and push them like so,

```
$ git commit -m "desciption of changes"
$ git push origin NAME-OF-YOUR-BRANCH
```

Go to https://github.com/alexlyttle/asteroloc8 and you should see the option to "Compare and open a pull request". Click this and submit your request. Get in touch with me (Alex Lyttle) on the Slack channel if you have any questions.

## Contributors

TODO: list of contributors
